@@ -102,12 +102,13 @@ if __name__ == '__main__':
         modify_riv_pars()
     if apexmf_con.loc['pp_included', 'vals'] != 'n':
         pp_included = apexmf_con.loc['pp_included','vals'].strip('][').split(', ')
-        pp_included = [i for i in pp_included]   
+        pp_included = [i.replace("'", "").strip() for i in pp_included]  
         modify_hk_sy_pars_pp(pp_included)
     # execute model
     execute_apexmf()
     # extract sims
-    if apexmf_con.loc['cha_file', 'vals'] != 'n' and apexmf_con.loc['fdc', 'vals'] != 'n':
+    # if apexmf_con.loc['cha_file', 'vals'] != 'n' and apexmf_con.loc['fdc', 'vals'] != 'n':
+    if apexmf_con.loc['cha_file', 'vals'] != 'n':
         subs = apexmf_con.loc['subs','vals'].strip('][').split(', ')
         subs = [int(i) for i in subs]
         extract_stf_results(cha_file, subs, sim_start, cal_start, cal_end)
